pub async fn run(
application: Arc<SomaApplication>,
invocation: CliInvocation,
io: &mut dyn CliIo,
) -> Result<ExitCode, CliError>Expand description
Run a CLI command, print the result, and exit.
Doctor, Watch, Setup, and package generation are handled by the app
composition layer because they are process infrastructure rather than
product actions.